==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/autoscaling/kotlin/inputs/PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.autoscaling.kotlin.inputs

import com.pulumi.aws.autoscaling.inputs.PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property expression Math expression used on the returned metric. You must specify either `expression` or `metric_stat`, but not both.
 * @property id Short name for the metric used in target tracking scaling policy.
 * @property label Human-readable label for this metric or expression.
 * @property metricStat Structure that defines CloudWatch metric to be used in target tracking scaling policy. You must specify either `expression` or `metric_stat`, but not both.
 * @property returnData Boolean that indicates whether to return the timestamps and raw data values of this metric, the default is true
 */
public data class PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricArgs(
    public val expression: Output<String>? = null,
    public val id: Output<String>,
    public val label: Output<String>? = null,
    public val metricStat:
    Output<PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricMetricStatArgs>? =
        null,
    public val returnData: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.autoscaling.inputs.PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricArgs> {
    override fun toJava():
        com.pulumi.aws.autoscaling.inputs.PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricArgs =
        com.pulumi.aws.autoscaling.inputs.PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricArgs.builder()
            .expression(expression?.applyValue({ args0 -> args0 }))
            .id(id.applyValue({ args0 -> args0 }))
            .label(label?.applyValue({ args0 -> args0 }))
            .metricStat(metricStat?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .returnData(returnData?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricArgs].
 */
@PulumiTagMarker
public class PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricArgsBuilder
internal constructor() {
    private var expression: Output<String>? = null

    private var id: Output<String>? = null

    private var label: Output<String>? = null

    private var metricStat:
        Output<PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricMetricStatArgs>? =
        null

    private var returnData: Output<Boolean>? = null

    /**
     * @param value Math expression used on the returned metric. You must specify either `expression` or `metric_stat`, but not both.
     */
    @JvmName("dagkmxdnnovdrqbj")
    public suspend fun expression(`value`: Output<String>) {
        this.expression = value
    }

    /**
     * @param value Short name for the metric used in target tracking scaling policy.
     */
    @JvmName("mddtpgirsdldoarr")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Human-readable label for this metric or expression.
     */
    @JvmName("iqsifmdcjdfshwic")
    public suspend fun label(`value`: Output<String>) {
        this.label = value
    }

    /**
     * @param value Structure that defines CloudWatch metric to be used in target tracking scaling policy. You must specify either `expression` or `metric_stat`, but not both.
     */
    @JvmName("xwapmceosxukkmgr")
    public suspend
    fun metricStat(`value`: Output<PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricMetricStatArgs>) {
        this.metricStat = value
    }

    /**
     * @param value Boolean that indicates whether to return the timestamps and raw data values of this metric, the default is true
     */
    @JvmName("wllhcecciwsopivt")
    public suspend fun returnData(`value`: Output<Boolean>) {
        this.returnData = value
    }

    /**
     * @param value Math expression used on the returned metric. You must specify either `expression` or `metric_stat`, but not both.
     */
    @JvmName("abundgphgeawcnjs")
    public suspend fun expression(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.expression = mapped
    }

    /**
     * @param value Short name for the metric used in target tracking scaling policy.
     */
    @JvmName("dqnlbiskxrbomrsj")
    public suspend fun id(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Human-readable label for this metric or expression.
     */
    @JvmName("jlreljnapkpjthle")
    public suspend fun label(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.label = mapped
    }

    /**
     * @param value Structure that defines CloudWatch metric to be used in target tracking scaling policy. You must specify either `expression` or `metric_stat`, but not both.
     */
    @JvmName("hchggofbhmrgqpox")
    public suspend
    fun metricStat(`value`: PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricMetricStatArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.metricStat = mapped
    }

    /**
     * @param argument Structure that defines CloudWatch metric to be used in target tracking scaling policy. You must specify either `expression` or `metric_stat`, but not both.
     */
    @JvmName("lflapiwinqkgwuvf")
    public suspend
    fun metricStat(argument: suspend PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricMetricStatArgsBuilder.() -> Unit) {
        val toBeMapped =
            PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricMetricStatArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.metricStat = mapped
    }

    /**
     * @param value Boolean that indicates whether to return the timestamps and raw data values of this metric, the default is true
     */
    @JvmName("ekwpjnmpkjtykclc")
    public suspend fun returnData(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.returnData = mapped
    }

    internal fun build(): PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricArgs =
        PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricArgs(
            expression = expression,
            id = id ?: throw PulumiNullFieldException("id"),
            label = label,
            metricStat = metricStat,
            returnData = returnData,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/autoscaling/kotlin/inputs/PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.autoscaling.kotlin.inputs

import com.pulumi.aws.autoscaling.inputs.PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property expression Math expression used on the returned metric. You must specify either `expression` or `metric_stat`, but not both.
 * @property id Short name for the metric used in target tracking scaling policy.
 * @property label Human-readable label for this metric or expression.
 * @property metricStat Structure that defines CloudWatch metric to be used in target tracking scaling policy. You must specify either `expression` or `metric_stat`, but not both.
 * @property returnData Boolean that indicates whether to return the timestamps and raw data values of this metric, the default is true
 */
public data class PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricArgs(
    public val expression: Output<String>? = null,
    public val id: Output<String>,
    public val label: Output<String>? = null,
    public val metricStat: Output<PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricMetricStatArgs>? =
        null,
    public val returnData: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.autoscaling.inputs.PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricArgs> {
    override fun toJava(): com.pulumi.aws.autoscaling.inputs.PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricArgs =
        com.pulumi.aws.autoscaling.inputs.PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricArgs.builder()
            .expression(expression?.applyValue({ args0 -> args0 }))
            .id(id.applyValue({ args0 -> args0 }))
            .label(label?.applyValue({ args0 -> args0 }))
            .metricStat(metricStat?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .returnData(returnData?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricArgs].
 */
@PulumiTagMarker
public class PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricArgsBuilder
internal constructor() {
    private var expression: Output<String>? = null

    private var id: Output<String>? = null

    private var label: Output<String>? = null

    private var metricStat:
        Output<PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricMetricStatArgs>? =
        null

    private var returnData: Output<Boolean>? = null

    /**
     * @param value Math expression used on the returned metric. You must specify either `expression` or `metric_stat`, but not both.
     */
    @JvmName("mvesvmovrrdbpkbk")
    public suspend fun expression(`value`: Output<String>) {
        this.expression = value
    }

    /**
     * @param value Short name for the metric used in target tracking scaling policy.
     */
    @JvmName("xjlmedmckntfipic")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Human-readable label for this metric or expression.
     */
    @JvmName("iyjiyuwttthqfjmi")
    public suspend fun label(`value`: Output<String>) {
        this.label = value
    }

    /**
     * @param value Structure that defines CloudWatch metric to be used in target tracking scaling policy. You must specify either `expression` or `metric_stat`, but not both.
     */
    @JvmName("jiwrcbqtuekityyo")
    public suspend fun metricStat(`value`: Output<PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricMetricStatArgs>) {
        this.metricStat = value
    }

    /**
     * @param value Boolean that indicates whether to return the timestamps and raw data values of this metric, the default is true
     */
    @JvmName("qptowvljrbuwpewv")
    public suspend fun returnData(`value`: Output<Boolean>) {
        this.returnData = value
    }

    /**
     * @param value Math expression used on the returned metric. You must specify either `expression` or `metric_stat`, but not both.
     */
    @JvmName("oqruwtkblfonkmpr")
    public suspend fun expression(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.expression = mapped
    }

    /**
     * @param value Short name for the metric used in target tracking scaling policy.
     */
    @JvmName("ocsbphyaawrepnqn")
    public suspend fun id(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Human-readable label for this metric or expression.
     */
    @JvmName("juxrtfnmetmosjau")
    public suspend fun label(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.label = mapped
    }

    /**
     * @param value Structure that defines CloudWatch metric to be used in target tracking scaling policy. You must specify either `expression` or `metric_stat`, but not both.
     */
    @JvmName("jmevirhyagspgsuo")
    public suspend fun metricStat(`value`: PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricMetricStatArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.metricStat = mapped
    }

    /**
     * @param argument Structure that defines CloudWatch metric to be used in target tracking scaling policy. You must specify either `expression` or `metric_stat`, but not both.
     */
    @JvmName("yoyrcgwfaiygcucc")
    public suspend fun metricStat(argument: suspend PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricMetricStatArgsBuilder.() -> Unit) {
        val toBeMapped =
            PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricMetricStatArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.metricStat = mapped
    }

    /**
     * @param value Boolean that indicates whether to return the timestamps and raw data values of this metric, the default is true
     */
    @JvmName("wwlnrkjbnfvxpiry")
    public suspend fun returnData(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.returnData = mapped
    }

    internal fun build(): PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricArgs =
        PolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricArgs(
            expression = expression,
            id = id ?: throw PulumiNullFieldException("id"),
            label = label,
            metricStat = metricStat,
            returnData = returnData,
        )
}
